======
Models
======

Kogia Core
==========

``ArchivableModel``
-------------------

.. autoclass:: kogia.core.models.ArchivableModel
   :members:

``OrderableModel``
------------------

.. autoclass:: kogia.core.models.OrderableModel
   :members:

``OwnableModel``
----------------

.. autoclass:: kogia.core.models.OwnableModel
   :members:

``PublishableModel``
--------------------

.. autoclass:: kogia.core.models.PublishableModel
   :members:

``SEOModel``
------------

.. autoclass:: kogia.core.models.SEOModel
   :members:

``UUIDModel``
-------------

.. autoclass:: kogia.core.models.UUIDModel
   :members:

``VisibilityStatusModel``
-------------------------

.. autoclass:: kogia.core.models.VisibilityStatusModel
   :members:


Kogia Intl
==========

``TranslationModel``
--------------------

.. autoclass:: kogia.intl.models.TranslationModel
   :members:


Kogia Pages
===========

``AbstractPage``
----------------

.. autoclass:: kogia.pages.models.AbstractPage
   :members:

``AbstractPageTranslation``
---------------------------

.. autoclass:: kogia.pages.models.AbstractPageTranslation
   :members:
